summaryrefslogtreecommitdiff
path: root/usr/src/lib/libc/common/sys
diff options
context:
space:
mode:
Diffstat (limited to 'usr/src/lib/libc/common/sys')
-rw-r--r--usr/src/lib/libc/common/sys/_so_accept.s18
-rw-r--r--usr/src/lib/libc/common/sys/_so_connect.s17
-rw-r--r--usr/src/lib/libc/common/sys/_so_recv.s15
-rw-r--r--usr/src/lib/libc/common/sys/_so_recvfrom.s19
-rw-r--r--usr/src/lib/libc/common/sys/_so_recvmsg.s17
-rw-r--r--usr/src/lib/libc/common/sys/_so_send.s17
-rw-r--r--usr/src/lib/libc/common/sys/_so_sendmsg.s17
-rw-r--r--usr/src/lib/libc/common/sys/_so_sendto.s19
-rw-r--r--usr/src/lib/libc/common/sys/close.s19
-rw-r--r--usr/src/lib/libc/common/sys/creat.s21
-rw-r--r--usr/src/lib/libc/common/sys/fcntl.s (renamed from usr/src/lib/libc/common/sys/__fcntl.s)15
-rw-r--r--usr/src/lib/libc/common/sys/fdsync.s15
-rw-r--r--usr/src/lib/libc/common/sys/fstat.s11
-rw-r--r--usr/src/lib/libc/common/sys/getmsg.s16
-rw-r--r--usr/src/lib/libc/common/sys/getpmsg.s15
-rw-r--r--usr/src/lib/libc/common/sys/ioctl.s10
-rw-r--r--usr/src/lib/libc/common/sys/open.s17
-rw-r--r--usr/src/lib/libc/common/sys/pause.s15
-rw-r--r--usr/src/lib/libc/common/sys/pread.s23
-rw-r--r--usr/src/lib/libc/common/sys/putmsg.s17
-rw-r--r--usr/src/lib/libc/common/sys/putpmsg.s17
-rw-r--r--usr/src/lib/libc/common/sys/pwrite.s26
-rw-r--r--usr/src/lib/libc/common/sys/read.s15
-rw-r--r--usr/src/lib/libc/common/sys/readv.s17
-rw-r--r--usr/src/lib/libc/common/sys/rename.s (renamed from usr/src/lib/libc/common/sys/_rename.s)21
-rw-r--r--usr/src/lib/libc/common/sys/stat.s11
-rw-r--r--usr/src/lib/libc/common/sys/waitid.s15
-rw-r--r--usr/src/lib/libc/common/sys/write.s15
-rw-r--r--usr/src/lib/libc/common/sys/writev.s17
29 files changed, 231 insertions, 256 deletions
diff --git a/usr/src/lib/libc/common/sys/_so_accept.s b/usr/src/lib/libc/common/sys/_so_accept.s
index cd94ffe1f8..b737628af8 100644
--- a/usr/src/lib/libc/common/sys/_so_accept.s
+++ b/usr/src/lib/libc/common/sys/_so_accept.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,12 +31,11 @@
.file "%M%"
-/* C library -- _so_accept */
-/* int _so_accept (int socket, struct sockaddr *name, int *namelen, */
-/* int vers); */
+/* C library -- __so_accept */
+/* int __so_accept(int sock, struct sockaddr *addr, int *addrlen, int vers) */
#include "SYS.h"
- SYSCALL2_RVAL1(_so_accept,accept)
+ SYSCALL2_RVAL1(__so_accept,accept)
RET
- SET_SIZE(_so_accept)
+ SET_SIZE(__so_accept)
diff --git a/usr/src/lib/libc/common/sys/_so_connect.s b/usr/src/lib/libc/common/sys/_so_connect.s
index ede794d28c..2eb16007a7 100644
--- a/usr/src/lib/libc/common/sys/_so_connect.s
+++ b/usr/src/lib/libc/common/sys/_so_connect.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,11 @@
.file "%M%"
-/* C library -- _so_connect */
-/* int _so_connect (int socket, struct sockaddr *name, int namelen, int vers); */
+/* C library -- __so_connect */
+/* int __so_connect(int sock, struct sockaddr *addr, int addrlen, int vers) */
#include "SYS.h"
- SYSCALL2_RVAL1(_so_connect,connect)
+ SYSCALL2_RVAL1(__so_connect,connect)
RET
- SET_SIZE(_so_connect)
+ SET_SIZE(__so_connect)
diff --git a/usr/src/lib/libc/common/sys/_so_recv.s b/usr/src/lib/libc/common/sys/_so_recv.s
index 6fb1eaac52..2b92fe77d8 100644
--- a/usr/src/lib/libc/common/sys/_so_recv.s
+++ b/usr/src/lib/libc/common/sys/_so_recv.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,10 +32,10 @@
.file "%M%"
/* C library -- _so_recv */
-/* int _so_recv (int socket, void *buffer, size_t len, int flags); */
+/* int __so_recv(int sock, void *buffer, size_t len, int flags) */
#include "SYS.h"
- SYSCALL2_RESTART_RVAL1(_so_recv,recv)
+ SYSCALL2_RESTART_RVAL1(__so_recv,recv)
RET
- SET_SIZE(_so_recv)
+ SET_SIZE(__so_recv)
diff --git a/usr/src/lib/libc/common/sys/_so_recvfrom.s b/usr/src/lib/libc/common/sys/_so_recvfrom.s
index 95b3d4ac99..d5b53892ad 100644
--- a/usr/src/lib/libc/common/sys/_so_recvfrom.s
+++ b/usr/src/lib/libc/common/sys/_so_recvfrom.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,14 +31,14 @@
.file "%M%"
-/* C library -- _so_recvfrom */
+/* C library -- __so_recvfrom */
/*
- * int _so_recvfrom (int socket, void *buffer, size_t len, int flags,
- * struct sockaddr *address, size_t *address_len);
+ * int __so_recvfrom(int sock, void *buffer, size_t len, int flags,
+ * struct sockaddr *addr, size_t *addrlen)
*/
#include "SYS.h"
- SYSCALL2_RESTART_RVAL1(_so_recvfrom,recvfrom)
+ SYSCALL2_RESTART_RVAL1(__so_recvfrom,recvfrom)
RET
- SET_SIZE(_so_recvfrom)
+ SET_SIZE(__so_recvfrom)
diff --git a/usr/src/lib/libc/common/sys/_so_recvmsg.s b/usr/src/lib/libc/common/sys/_so_recvmsg.s
index 953faf6105..15b3e31fe0 100644
--- a/usr/src/lib/libc/common/sys/_so_recvmsg.s
+++ b/usr/src/lib/libc/common/sys/_so_recvmsg.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,11 @@
.file "%M%"
-/* C library -- _so_recvmsg */
-/* int _so_recvmsg (int socket, struct msghdr *msg, int flags); */
+/* C library -- __so_recvmsg */
+/* int __so_recvmsg(int sock, struct msghdr *msg, int flags) */
#include "SYS.h"
- SYSCALL2_RESTART(_so_recvmsg,recvmsg)
+ SYSCALL2_RESTART_RVAL1(__so_recvmsg,recvmsg)
RET
- SET_SIZE(_so_recvmsg)
+ SET_SIZE(__so_recvmsg)
diff --git a/usr/src/lib/libc/common/sys/_so_send.s b/usr/src/lib/libc/common/sys/_so_send.s
index 706f02ac6d..285193b2be 100644
--- a/usr/src/lib/libc/common/sys/_so_send.s
+++ b/usr/src/lib/libc/common/sys/_so_send.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,11 @@
.file "%M%"
-/* C library -- _so_send */
-/* int _so_send (int socket, void *buffer, size_t len, int flags); */
+/* C library -- __so_send */
+/* int __so_send(int socket, const void *buffer, size_t len, int flags) */
#include "SYS.h"
- SYSCALL2_RESTART_RVAL1(_so_send,send)
+ SYSCALL2_RESTART_RVAL1(__so_send,send)
RET
- SET_SIZE(_so_send)
+ SET_SIZE(__so_send)
diff --git a/usr/src/lib/libc/common/sys/_so_sendmsg.s b/usr/src/lib/libc/common/sys/_so_sendmsg.s
index ce9cb079d2..2e19c716f3 100644
--- a/usr/src/lib/libc/common/sys/_so_sendmsg.s
+++ b/usr/src/lib/libc/common/sys/_so_sendmsg.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,11 @@
.file "%M%"
-/* C library -- _so_sendmsg */
-/* int _so_sendmsg (int socket, struct msghdr *msg, int flags); */
+/* C library -- __so_sendmsg */
+/* int __so_sendmsg(int sock, const struct msghdr *msg, int flags) */
#include "SYS.h"
- SYSCALL2_RESTART_RVAL1(_so_sendmsg,sendmsg)
+ SYSCALL2_RESTART_RVAL1(__so_sendmsg,sendmsg)
RET
- SET_SIZE(_so_sendmsg)
+ SET_SIZE(__so_sendmsg)
diff --git a/usr/src/lib/libc/common/sys/_so_sendto.s b/usr/src/lib/libc/common/sys/_so_sendto.s
index 8c5374a9d6..cb5444ba28 100644
--- a/usr/src/lib/libc/common/sys/_so_sendto.s
+++ b/usr/src/lib/libc/common/sys/_so_sendto.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,14 +31,14 @@
.file "%M%"
-/* C library -- _so_sendto */
+/* C library -- __so_sendto */
/*
- * int _so_sendto (int socket, void *buffer, size_t len, int flags,
- * struct sockaddr *address, size_t address_len);
+ * int __so_sendto(int sock, const void *buffer, size_t len, int flags,
+ * const struct sockaddr *addr, int addrlen);
*/
#include "SYS.h"
- SYSCALL2_RESTART_RVAL1(_so_sendto,sendto)
+ SYSCALL2_RESTART_RVAL1(__so_sendto,sendto)
RET
- SET_SIZE(_so_sendto)
+ SET_SIZE(__so_sendto)
diff --git a/usr/src/lib/libc/common/sys/close.s b/usr/src/lib/libc/common/sys/close.s
index c8fa248014..c88472019c 100644
--- a/usr/src/lib/libc/common/sys/close.s
+++ b/usr/src/lib/libc/common/sys/close.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,12 +31,12 @@
.file "%M%"
-/* C library -- close */
-/* int close(int fildes) */
+/* C library -- close */
+/* int __close(int fildes) */
#include "SYS.h"
- ANSI_PRAGMA_WEAK2(_private_close,_close,function)
- SYSCALL_RVAL1(close)
+ ANSI_PRAGMA_WEAK2(_private_close,__close,function)
+ SYSCALL2_RVAL1(__close,close)
RETC
- SET_SIZE(close)
+ SET_SIZE(__close)
diff --git a/usr/src/lib/libc/common/sys/creat.s b/usr/src/lib/libc/common/sys/creat.s
index fa6800ad11..45530500d0 100644
--- a/usr/src/lib/libc/common/sys/creat.s
+++ b/usr/src/lib/libc/common/sys/creat.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -36,18 +35,18 @@
#if !defined(_LARGEFILE_SOURCE)
/* C library -- creat */
-/* int creat(char *path, mode_t mode) */
+/* int __creat(char *path, mode_t mode) */
- SYSCALL_RVAL1(creat)
+ SYSCALL2_RVAL1(__creat,creat)
RET
- SET_SIZE(creat)
+ SET_SIZE(__creat)
#else
/* C library -- creat64 */
-/* int creat64(char *path, mode_t mode) */
+/* int __creat64(char *path, mode_t mode) */
- SYSCALL_RVAL1(creat64)
+ SYSCALL2_RVAL1(__creat64,creat64)
RET
- SET_SIZE(creat64)
+ SET_SIZE(__creat64)
#endif
diff --git a/usr/src/lib/libc/common/sys/fdsync.s b/usr/src/lib/libc/common/sys/fdsync.s
index 52e561346c..61775f9bd1 100644
--- a/usr/src/lib/libc/common/sys/fdsync.s
+++ b/usr/src/lib/libc/common/sys/fdsync.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,12 +32,10 @@
.file "%M%"
/* Underlying function for C library(fsync) and POSIX(fdatasync)*/
-/* int fdsync(int fildes,int flag) */
+/* int __fdsync(int fildes, int flag) */
#include "SYS.h"
- ENTRY(__fdsync)
- SYSTRAP_RVAL1(fdsync)
- SYSCERROR
+ SYSCALL2_RVAL1(__fdsync,fdsync)
RETC
SET_SIZE(__fdsync)
diff --git a/usr/src/lib/libc/common/sys/fstat.s b/usr/src/lib/libc/common/sys/fstat.s
index 13ce8eb77b..00740c5cd0 100644
--- a/usr/src/lib/libc/common/sys/fstat.s
+++ b/usr/src/lib/libc/common/sys/fstat.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -47,6 +46,7 @@
#if !defined(_LARGEFILE_SOURCE)
+ ANSI_PRAGMA_WEAK2(_private_fstat,fstat,function)
SYSCALL_RVAL1(fstat)
RETC
SET_SIZE(fstat)
@@ -56,6 +56,7 @@
/* C library -- fstat64 transitional large file API */
/* int fstat64 (int fildes, struct stat64 *buf) */
+ ANSI_PRAGMA_WEAK2(_private_fstat64,fstat64,function)
SYSCALL_RVAL1(fstat64)
RETC
SET_SIZE(fstat64)
diff --git a/usr/src/lib/libc/common/sys/getmsg.s b/usr/src/lib/libc/common/sys/getmsg.s
index 39e8aa2524..333aa6632a 100644
--- a/usr/src/lib/libc/common/sys/getmsg.s
+++ b/usr/src/lib/libc/common/sys/getmsg.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,12 +32,11 @@
.file "%M%"
/* C library -- getmsg */
-/* int getmsg (int fd, struct strbuf *ctlptr, */
+/* int __getmsg(int fd, struct strbuf *ctlptr, */
/* struct strbuf *dataptr, int *flags) */
-#include <sys/asm_linkage.h>
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(getmsg)
+ SYSCALL2_RESTART_RVAL1(__getmsg,getmsg)
RET
- SET_SIZE(getmsg)
+ SET_SIZE(__getmsg)
diff --git a/usr/src/lib/libc/common/sys/getpmsg.s b/usr/src/lib/libc/common/sys/getpmsg.s
index 9594e79111..c82d8b09c6 100644
--- a/usr/src/lib/libc/common/sys/getpmsg.s
+++ b/usr/src/lib/libc/common/sys/getpmsg.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,11 +32,11 @@
.file "%M%"
/* C library -- getpmsg */
-/* int getpmsg (int fd, struct strbuf *ctlptr, */
+/* int __getpmsg(int fd, struct strbuf *ctlptr, */
/* struct strbuf *dataptr, int pri, int *flags) */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(getpmsg)
+ SYSCALL2_RESTART_RVAL1(__getpmsg,getpmsg)
RET
- SET_SIZE(getpmsg)
+ SET_SIZE(__getpmsg)
diff --git a/usr/src/lib/libc/common/sys/ioctl.s b/usr/src/lib/libc/common/sys/ioctl.s
index 6009bee136..94e2e3ceae 100644
--- a/usr/src/lib/libc/common/sys/ioctl.s
+++ b/usr/src/lib/libc/common/sys/ioctl.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -41,6 +40,7 @@
#include "SYS.h"
+ ANSI_PRAGMA_WEAK2(_private_ioctl,ioctl,function)
SYSCALL_RESTART_RVAL1(ioctl)
RET
SET_SIZE(ioctl)
diff --git a/usr/src/lib/libc/common/sys/open.s b/usr/src/lib/libc/common/sys/open.s
index df5386a726..2ebb074603 100644
--- a/usr/src/lib/libc/common/sys/open.s
+++ b/usr/src/lib/libc/common/sys/open.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -38,9 +37,9 @@
/* C library -- open */
/* int open (const char *path, int oflag, [ mode_t mode ] ) */
- SYSCALL2_RVAL1(__open,open)
+ SYSCALL2_RVAL1(__open_syscall,open)
RET
- SET_SIZE(__open)
+ SET_SIZE(__open_syscall)
#else
/*
@@ -48,8 +47,8 @@
* int open64 (const char *path, int oflag, [ mode_t mode ] )
*/
- SYSCALL2_RVAL1(__open64,open64)
+ SYSCALL2_RVAL1(__open64_syscall,open64)
RET
- SET_SIZE(__open64)
+ SET_SIZE(__open64_syscall)
#endif
diff --git a/usr/src/lib/libc/common/sys/pause.s b/usr/src/lib/libc/common/sys/pause.s
index e07ed61397..2da6f69639 100644
--- a/usr/src/lib/libc/common/sys/pause.s
+++ b/usr/src/lib/libc/common/sys/pause.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,10 +32,10 @@
.file "%M%"
/* C library - pause */
-/* int pause (void); */
+/* int __pause(void); */
#include "SYS.h"
- SYSCALL_RVAL1(pause)
+ SYSCALL2_RVAL1(__pause,pause)
RET
- SET_SIZE(pause)
+ SET_SIZE(__pause)
diff --git a/usr/src/lib/libc/common/sys/pread.s b/usr/src/lib/libc/common/sys/pread.s
index 31207d81d6..0a08814dde 100644
--- a/usr/src/lib/libc/common/sys/pread.s
+++ b/usr/src/lib/libc/common/sys/pread.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,24 +31,24 @@
.file "%M%"
-/* C library -- pread */
-/* int pread (int fildes, void *buf, unsigned nbyte, off_t offset); */
+/* C library -- pread */
+/* ssize_t __pread(int, void *, size_t, off_t); */
#include "SYS.h"
#if !defined(_LARGEFILE_SOURCE)
- SYSCALL_RESTART_RVAL1(pread)
+ SYSCALL2_RESTART_RVAL1(__pread,pread)
RET
- SET_SIZE(pread)
+ SET_SIZE(__pread)
#else
/* C library -- pread64 transitional large file API */
-/* ssize_t pread(int, void *, size_t, off64_t); */
+/* ssize_t __pread(int, void *, size_t, off64_t); */
- SYSCALL_RESTART_RVAL1(pread64)
+ SYSCALL2_RESTART_RVAL1(__pread64,pread64)
RET
- SET_SIZE(pread64)
+ SET_SIZE(__pread64)
#endif
diff --git a/usr/src/lib/libc/common/sys/putmsg.s b/usr/src/lib/libc/common/sys/putmsg.s
index 423e16f1a1..66ccec85e0 100644
--- a/usr/src/lib/libc/common/sys/putmsg.s
+++ b/usr/src/lib/libc/common/sys/putmsg.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,11 +32,11 @@
.file "%M%"
/* C library -- putmsg */
-/* int putmsg (int fd, struct const strbuf *ctlptr,
- struct const strbuf *dataptr, int *flags) */
+/* int __putmsg(int fd, struct const strbuf *ctlptr, */
+/* struct const strbuf *dataptr, int *flags) */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(putmsg)
+ SYSCALL2_RESTART_RVAL1(__putmsg,putmsg)
RET
- SET_SIZE(putmsg)
+ SET_SIZE(__putmsg)
diff --git a/usr/src/lib/libc/common/sys/putpmsg.s b/usr/src/lib/libc/common/sys/putpmsg.s
index f2a56f3006..e97587d007 100644
--- a/usr/src/lib/libc/common/sys/putpmsg.s
+++ b/usr/src/lib/libc/common/sys/putpmsg.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,11 +32,11 @@
.file "%M%"
/* C library -- putpmsg */
-/* int putpmsg (int fd, struct const strbuf *ctlptr,
- struct const strbuf *dataptr, int *flags) */
+/* int __putpmsg(int fd, struct const strbuf *ctlptr, */
+/* struct const strbuf *dataptr, int *flags) */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(putpmsg)
+ SYSCALL2_RESTART_RVAL1(__putpmsg,putpmsg)
RET
- SET_SIZE(putpmsg)
+ SET_SIZE(__putpmsg)
diff --git a/usr/src/lib/libc/common/sys/pwrite.s b/usr/src/lib/libc/common/sys/pwrite.s
index cff21b3c20..61d8b67544 100644
--- a/usr/src/lib/libc/common/sys/pwrite.s
+++ b/usr/src/lib/libc/common/sys/pwrite.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,8 +18,9 @@
*
* CDDL HEADER END
*/
+
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -28,24 +28,24 @@
.file "%M%"
-/* C library -- pwrite */
-/* int pwrite (int fildes, const void *buf, unsigned nbyte, off_t offset); */
-
#include "SYS.h"
#if !defined(_LARGEFILE_SOURCE)
- SYSCALL_RESTART_RVAL1(pwrite)
+/* C library -- pwrite */
+/* ssize_t __pwrite(int, const void *, size_t, off_t); */
+
+ SYSCALL2_RESTART_RVAL1(__pwrite,pwrite)
RET
- SET_SIZE(pwrite)
+ SET_SIZE(__pwrite)
#else
-/* C library -- lseek64 transitional large file API */
-/* ssize_t pwrite(int, void *, size_t, off64_t); */
+/* C library -- pwrite64 transitional large file API */
+/* ssize_t __pwrite64(int, const void *, size_t, off64_t); */
- SYSCALL_RESTART_RVAL1(pwrite64)
+ SYSCALL2_RESTART_RVAL1(__pwrite64,pwrite64)
RET
- SET_SIZE(pwrite64)
+ SET_SIZE(__pwrite64)
#endif
diff --git a/usr/src/lib/libc/common/sys/read.s b/usr/src/lib/libc/common/sys/read.s
index f124bc7b68..72db14e879 100644
--- a/usr/src/lib/libc/common/sys/read.s
+++ b/usr/src/lib/libc/common/sys/read.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,10 +32,10 @@
.file "%M%"
/* C library -- read */
-/* int read (int fildes, void *buf, unsigned nbyte); */
+/* ssize_t __read(int fildes, void *buf, size_t nbyte); */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(read)
+ SYSCALL2_RESTART_RVAL1(__read,read)
RET
- SET_SIZE(read)
+ SET_SIZE(__read)
diff --git a/usr/src/lib/libc/common/sys/readv.s b/usr/src/lib/libc/common/sys/readv.s
index c8990a99c2..3dd7136416 100644
--- a/usr/src/lib/libc/common/sys/readv.s
+++ b/usr/src/lib/libc/common/sys/readv.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,11 @@
.file "%M%"
-/* C library -- readv */
-/* nt readv(int fildes, void *iovp[], int iovcnt[]) */
+/* C library -- readv */
+/* ssize_t __readv(int fd, const struct iovec *iovp, int iovcnt) */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(readv)
+ SYSCALL2_RESTART_RVAL1(__readv,readv)
RET
- SET_SIZE(readv)
+ SET_SIZE(__readv)
diff --git a/usr/src/lib/libc/common/sys/_rename.s b/usr/src/lib/libc/common/sys/rename.s
index 417722b819..ce31680d89 100644
--- a/usr/src/lib/libc/common/sys/_rename.s
+++ b/usr/src/lib/libc/common/sys/rename.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,15 @@
.file "%M%"
-/* C library -- _rename */
-/* _rename() is the system call version of rename() */
+/* C library -- rename */
+/* int rename(const char *old, const char *new); */
+
+#include <sys/asm_linkage.h>
+
+ ANSI_PRAGMA_WEAK(rename,function)
#include "SYS.h"
- SYSCALL2_RVAL1(_rename,rename)
+ SYSCALL_RVAL1(rename)
RETC
- SET_SIZE(_rename)
+ SET_SIZE(rename)
diff --git a/usr/src/lib/libc/common/sys/stat.s b/usr/src/lib/libc/common/sys/stat.s
index ae624e6b89..e311c337f0 100644
--- a/usr/src/lib/libc/common/sys/stat.s
+++ b/usr/src/lib/libc/common/sys/stat.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -47,6 +46,7 @@
#if !defined(_LARGEFILE_SOURCE)
+ ANSI_PRAGMA_WEAK2(_private_stat,stat,function)
SYSCALL_RVAL1(stat)
RETC
SET_SIZE(stat)
@@ -56,6 +56,7 @@
/* C library -- stat64 - transitional API */
/* int stat64 (const char *path, struct stat64 *buf); */
+ ANSI_PRAGMA_WEAK2(_private_stat64,stat64,function)
SYSCALL_RVAL1(stat64)
RETC
SET_SIZE(stat64)
diff --git a/usr/src/lib/libc/common/sys/waitid.s b/usr/src/lib/libc/common/sys/waitid.s
index 14f728d58e..5b4a6dc2f3 100644
--- a/usr/src/lib/libc/common/sys/waitid.s
+++ b/usr/src/lib/libc/common/sys/waitid.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -38,8 +37,6 @@
#include "SYS.h"
- SYSREENTRY(waitid)
- SYSTRAP_RVAL1(waitsys)
- SYSRESTART(.restart_waitid)
+ SYSCALL2_RESTART_RVAL1(__waitid,waitid)
RETC
- SET_SIZE(waitid)
+ SET_SIZE(__waitid)
diff --git a/usr/src/lib/libc/common/sys/write.s b/usr/src/lib/libc/common/sys/write.s
index 1e19de56ec..d69ccb5f86 100644
--- a/usr/src/lib/libc/common/sys/write.s
+++ b/usr/src/lib/libc/common/sys/write.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -33,10 +32,10 @@
.file "%M%"
/* C library -- write */
-/* int write (int fildes, const void *buf, unsigned nbyte); */
+/* ssize_t __write(int fildes, const void *buf, size_t nbyte); */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(write)
+ SYSCALL2_RESTART_RVAL1(__write,write)
RET
- SET_SIZE(write)
+ SET_SIZE(__write)
diff --git a/usr/src/lib/libc/common/sys/writev.s b/usr/src/lib/libc/common/sys/writev.s
index 0d13868a48..9c793aec78 100644
--- a/usr/src/lib/libc/common/sys/writev.s
+++ b/usr/src/lib/libc/common/sys/writev.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,12 +18,12 @@
*
* CDDL HEADER END
*/
+
/* Copyright (c) 1988 AT&T */
/* All Rights Reserved */
-
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -32,11 +31,11 @@
.file "%M%"
-/* C library -- writev */
-/* int writev(fd, iovp, iovcnt) */
+/* C library -- writev */
+/* ssize_t __writev(int fd, const struct iovec *iovp, int iovcnt) */
#include "SYS.h"
- SYSCALL_RESTART_RVAL1(writev)
+ SYSCALL2_RESTART_RVAL1(__writev,writev)
RET
- SET_SIZE(writev)
+ SET_SIZE(__writev)
diff --git a/usr/src/lib/libc/common/sys/__fcntl.s b/usr/src/lib/libc/common/sys/fcntl.s
index 6628c7b4b6..df24860158 100644
--- a/usr/src/lib/libc/common/sys/__fcntl.s
+++ b/usr/src/lib/libc/common/sys/fcntl.s
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -19,8 +18,9 @@
*
* CDDL HEADER END
*/
+
/*
- * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -29,12 +29,11 @@
.file "%M%"
/*
* int fcntl(int fildes, int cmd [, arg])
*/
#include "SYS.h"
- ANSI_PRAGMA_WEAK2(_private_fcntl,__fcntl,function)
- SYSCALL2_RESTART_RVAL1(__fcntl,fcntl)
+ SYSCALL2_RESTART_RVAL1(__fcntl_syscall,fcntl)
RET
- SET_SIZE(__fcntl)
+ SET_SIZE(__fcntl_syscall)
@@ -29,12 +29,11 @@
.file "%M%"
/*
- * int fcntl(int fildes, int cmd [, arg])
+ * int __fcntl_syscall(int fildes, int cmd [, arg])
*/
#include "SYS.h"